@@ -10,7 +10,6 @@ from warnings import warn
 from . import xmlwriter
 from .utility import xl_color
 from .utility import xl_rowcol_to_cell
-from .utility import encode_utf8
 
 
 class Chart(xmlwriter.XMLwriter):
@@ -571,9 +570,6 @@ class Chart(xmlwriter.XMLwriter):
             'num_format_linked': options.get('num_format_linked'),
         }
 
-        # Encode any string options passed by the user.
-        axis['num_format'] = encode_utf8(axis['num_format'])
-
         if 'visible' in options:
             axis['visible'] = options.get('visible')
         else:
@@ -650,9 +646,6 @@ class Chart(xmlwriter.XMLwriter):
             name_formula = name
             name = ''
 
-        name = encode_utf8(name)
-        name_formula = encode_utf8(name_formula)
-
         return name, name_formula
 
     def _get_data_type(self, data):
